@@ -9,7 +9,7 @@ import threading
 from inspect import getsource
 from math import isnan
 from pathlib import Path
-from typing import Callable, Dict, List, Optional, Tuple, Union
+from typing import Callable, Dict, List, Optional, Union
 
 import numpy as np
 import pandas as pd
@@ -22,7 +22,7 @@ from zeno.api import ZenoOptions, ZenoParameters
 from zeno.classes.base import MetadataType, ZenoColumnType
 from zeno.classes.classes import MetricKey, TableRequest, ZenoColumn
 from zeno.classes.metadata import HistogramBucket, HistogramRequest
-from zeno.classes.projection import Points2D
+from zeno.classes.projection import Points2D, PointsColors
 from zeno.classes.report import Report
 from zeno.classes.slice import (
     FilterIds,
@@ -469,12 +469,12 @@ class ZenoBackend(object):
             elif col.metadata_type == MetadataType.CONTINUOUS:
                 ret_hist: List[HistogramBucket] = []  # type: ignore
                 df_col = df_col.fillna(0)
-                bins = np.histogram(df_col, bins="doane")
-                for i in range(len(bins[0])):
+                bins = np.histogram_bin_edges(df_col)
+                for i in range(len(bins) - 1):
                     ret_hist.append(
                         HistogramBucket(
-                            bucket=round(bins[1][i], 4),
-                            bucket_end=round(bins[1][i + 1], 4),
+                            bucket=bins[i],
+                            bucket_end=bins[i + 1],
                         )
                     )
                 res.append(ret_hist)
@@ -501,7 +501,30 @@ class ZenoBackend(object):
         ret: List[List[int]] = []
         for r in req.column_requests:
             col = r.column
-            ret.append([len(filter_table_single(filt_df, col, b)) for b in r.buckets])
+            if str(col) not in filt_df.columns:
+                ret.append([])
+            elif col.metadata_type == MetadataType.NOMINAL:
+                counts = filt_df.groupby([str(col)]).size()
+                ret.append(
+                    [
+                        counts[b.bucket] if b.bucket in counts else 0  # type: ignore
+                        for b in r.buckets
+                    ]
+                )
+            elif col.metadata_type == MetadataType.BOOLEAN:
+                ret.append(
+                    [filt_df[str(col)].sum(), len(filt_df) - filt_df[str(col)].sum()]
+                )
+            elif col.metadata_type == MetadataType.CONTINUOUS:
+                bucs = [b.bucket for b in r.buckets]
+                ret.append(
+                    filt_df.groupby([pd.cut(filt_df[str(col)], bucs)])  # type: ignore
+                    .size()
+                    .astype(int)
+                    .tolist()
+                )
+            else:
+                ret.append([])
         return ret
 
     def get_histogram_metric(
@@ -572,7 +595,7 @@ class ZenoBackend(object):
 
         return projection
 
-    def get_projection_colors(self, column: ZenoColumn) -> Tuple[List[int], List, str]:
+    def get_projection_colors(self, column: ZenoColumn) -> PointsColors:
         """Get colors for a projection based on a column.
 
         Args:
@@ -606,13 +629,16 @@ class ZenoBackend(object):
                 color_range = labels.astype(int).tolist()
             else:
                 color_range = [0] * len(series)
-        return color_range, unique.tolist(), metadata_type
+
+        return PointsColors(
+            color=color_range, domain=unique.tolist(), data_type=metadata_type
+        )
 
     def project_embed_into_2D(self, model: str, column: ZenoColumn) -> Points2D:
         """If the embedding exists, will use t-SNE to project into 2D."""
 
         points = Points2D(
-            x=[], y=[], color=[], domain=[], opacity=[], dataType="", ids=[]
+            x=[], y=[], color=[], domain=[], opacity=[], data_type="", ids=[]
         )
 
         # Can't project without an embedding
@@ -625,9 +651,9 @@ class ZenoBackend(object):
         points.x = projection[:, 0].tolist()
         points.y = projection[:, 1].tolist()
         color_results = self.get_projection_colors(column)
-        points.color = color_results[0]
-        points.domain = color_results[1]
-        points.dataType = color_results[2]
+        points.color = color_results.color
+        points.domain = color_results.domain
+        points.data_type = color_results.data_type
         points.ids = self.df[str(self.id_column)].to_list()
 
         return points
