@@ -13,6 +13,7 @@ from fastapi.staticfiles import StaticFiles
 
 from zeno.classes.base import ZenoColumn
 from zeno.classes.classes import (
+    ColorsProjectRequest,
     EmbedProject2DRequest,
     EntryRequest,
     MetricRequest,
@@ -22,7 +23,7 @@ from zeno.classes.classes import (
     ZenoVariables,
 )
 from zeno.classes.metadata import HistogramBucket, HistogramRequest
-from zeno.classes.projection import Points2D
+from zeno.classes.projection import Points2D, PointsColors
 from zeno.classes.report import Report
 from zeno.classes.slice import FilterPredicate, FilterPredicateGroup, Slice, SliceMetric
 from zeno.data_pipeline.zeno_backend import ZenoBackend
@@ -144,6 +145,10 @@ def get_server(zeno: ZenoBackend):
     def project_embed_into_2D(req: EmbedProject2DRequest):
         return zeno.project_embed_into_2D(req.model, req.column)
 
+    @api_app.post("/colors-project", tags=["zeno"], response_model=PointsColors)
+    def get_projection_colors(req: ColorsProjectRequest):
+        return zeno.get_projection_colors(req.column)
+
     @api_app.post("/entry", tags=["zeno"], response_model=str)
     def get_df_row_entry(req: EntryRequest):
         try:
